@@ -49,7 +49,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.CreateConsumerGroupResponse:
         """
-        创建消费组
+        创建消费组。
+        当前 API 适用集群：5.x 集群。4.x 集群的创建消费组接口文档见 [CreateRocketMQGroup](https://cloud.tencent.com/document/api/1179/63428)。
         """
         
         kwargs = {}
@@ -67,7 +68,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.CreateInstanceResponse:
         """
-        创建 RocketMQ 5.x 集群
+        创建 RocketMQ 5.x 集群。
+        当前 API 适用集群：5.x 集群。创建 4.x 专享/通用集群的接口文档见 [CreateRocketMQVipInstance](https://cloud.tencent.com/document/product/1179/95721)。
         """
         
         kwargs = {}
@@ -165,7 +167,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.CreateRoleResponse:
         """
-        添加角色
+        添加角色。
+        当前 API 适用集群：5.x 集群。4.x 集群的创建角色接口文档见 [CreateRocketMQRole](https://cloud.tencent.com/document/product/1179/107538)，给角色授权接口文档见 [CreateRocketMQEnvironmentRole](https://cloud.tencent.com/document/product/1179/107539)。
         """
         
         kwargs = {}
@@ -183,7 +186,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.CreateTopicResponse:
         """
-        创建主题
+        创建 RocketMQ 主题。
+        当前 API 适用集群：5.x 集群。4.x 集群的创建主题接口文档见 [CreateRocketMQTopic](https://cloud.tencent.com/document/api/1179/63426)
         """
         
         kwargs = {}
@@ -202,6 +206,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DeleteConsumerGroupResponse:
         """
         删除消费组。消费者组删除后，消费者组的所有配置和相关数据都会被清空，且无法找回。删除后，在线的消费者客户端会出现报错，建议您提前下线客户端。
+        当前 API 适用集群：5.x 集群。4.x 集群的删除消费组接口文档见 [DeleteRocketMQGroup](https://cloud.tencent.com/document/api/1179/63424)。
         """
         
         kwargs = {}
@@ -220,6 +225,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DeleteInstanceResponse:
         """
         删除 RocketMQ 5.x 集群，删除前请先删除正在使用的主题、消费组和角色信息。
+        当前 API 适用集群：5.x 集群。删除 4.x 集群接口文档见 [DeleteRocketMQVipInstance](https://cloud.tencent.com/document/product/1179/95802)。
         """
         
         kwargs = {}
@@ -318,6 +324,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DeleteRoleResponse:
         """
         删除角色。请确保该角色相关信息不在当前代码中被使用。删除角色后，原先使用该角色进行生产或消费消息的密钥（AccessKey 和 SecretKey）将立即失效。
+        当前 API 适用集群：5.x 集群。4.x 集群的删除角色接口文档见 [DeleteRocketMQRoles](https://cloud.tencent.com/document/product/1179/107536)，删除角色授权接口文档见 [DeleteRocketMQEnvironmentRoles](https://cloud.tencent.com/document/product/1179/107537)。
         """
         
         kwargs = {}
@@ -354,6 +361,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DeleteTopicResponse:
         """
         删除主题。主题删除后，主题的所有配置和相关数据都会被清空，且无法找回。
+        当前 API 适用集群：5.x 集群。4.x 集群的删除主题接口文档见 [DeleteRocketMQTopic](https://cloud.tencent.com/document/api/1179/63423)。
         """
         
         kwargs = {}
@@ -371,7 +379,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.DescribeConsumerClientResponse:
         """
-        查询消费者客户端详情
+        查询消费者客户端详情。
+        当前 API 适用集群：5.x 集群。4.x 集群的查询消费者客户端详情接口文档见 [DescribeRocketMQConsumerConnectionDetail](https://cloud.tencent.com/document/product/1179/102490)。
         """
         
         kwargs = {}
@@ -390,6 +399,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DescribeConsumerClientListResponse:
         """
         查询消费组下的客户端连接列表。
+        当前 API 适用集群：5.x 集群。4.x 集群的查询消费组下的客户端列表接口文档见 [DescribeRocketMQConsumerConnections](https://cloud.tencent.com/document/product/1179/100460)。
         """
         
         kwargs = {}
@@ -407,7 +417,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.DescribeConsumerGroupResponse:
         """
-        查询消费组详情
+        查询消费组详情。
+        当前 API 适用集群：5.x 集群。4.x 集群的查询消费组详情接口文档见 [DescribeRocketMQConsumerConnections](https://cloud.tencent.com/document/product/1179/100460)。
         """
         
         kwargs = {}
@@ -434,6 +445,7 @@ class TrocketClient(AbstractClient):
 
         Filters示例：
         [{ "Name": "ConsumeMessageOrderly", "Values": ["true"] }]
+        当前 API 适用集群：5.x 集群。4.x 集群的获取消费组列表接口文档见 [DescribeRocketMQGroups](https://cloud.tencent.com/document/api/1179/63420)。
         """
         
         kwargs = {}
@@ -452,6 +464,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DescribeConsumerLagResponse:
         """
         查询指定消费组堆积数。
+        当前 API 适用集群：4.x 集群和 5.x 集群。
         """
         
         kwargs = {}
@@ -498,6 +511,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DescribeInstanceResponse:
         """
         查询 RocketMQ 5.x 集群信息。
+        当前 API 适用集群：5.x 集群。查询 4.x 专享/通用集群信息的接口文档见 [DescribeRocketMQVipInstanceDetail](https://cloud.tencent.com/document/product/1179/86725)。
         """
         
         kwargs = {}
@@ -815,6 +829,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DescribeMessageListResponse:
         """
         查询消息列表。如果查询死信消息，请设置ConsumerGroup参数。
+        当前 API 适用集群：5.x 集群。4.x 集群的查询消息列表接口文档见 [DescribeRocketMQTopicMsgs](https://cloud.tencent.com/document/product/1179/97761)。
         """
         
         kwargs = {}
@@ -833,6 +848,7 @@ class TrocketClient(AbstractClient):
     ) -> models.DescribeMessageTraceResponse:
         """
         根据消息 ID 查询消息轨迹。
+        当前 API 适用集群：5.x 集群。4.x 集群查询消息轨迹接口文档见 [DescribeRocketMQMsgTrace](https://cloud.tencent.com/document/product/1179/97760)。
         """
         
         kwargs = {}
@@ -983,6 +999,7 @@ class TrocketClient(AbstractClient):
 
         Filters示例：
         [{ "Name": "RoleName", "Values": ["test_role"] }]
+        当前 API 适用集群：5.x 集群。4.x 集群的查询角色列表接口文档见 [DescribeRocketMQRoles](https://cloud.tencent.com/document/product/1179/107534)，查询角色授权列表接口文档见 [DescribeRocketMQEnvironmentRoles](https://cloud.tencent.com/document/product/1179/107535)。
         """
         
         kwargs = {}
@@ -1090,6 +1107,7 @@ class TrocketClient(AbstractClient):
 
         Filters示例：
          [{ "Name": "TopicName", "Values": ["test_topic"] }]
+        当前 API 适用集群：5.x 集群。4.x 集群的获取主题列表接口文档见 [DescribeRocketMQTopics](https://cloud.tencent.com/document/api/1179/63418)。
         """
         
         kwargs = {}
@@ -1184,7 +1202,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.ModifyConsumerGroupResponse:
         """
-        修改消费组属性
+        修改消费组属性。
+        当前 API 适用集群：5.x 集群。4.x 集群的修改消费组属性接口文档见 [ModifyRocketMQGroup](https://cloud.tencent.com/document/api/1179/63416)。
         """
         
         kwargs = {}
@@ -1203,6 +1222,7 @@ class TrocketClient(AbstractClient):
     ) -> models.ModifyInstanceResponse:
         """
         修改 RocketMQ 5.x 集群属性，仅支持修改运行中的集群。
+        当前 API 适用集群：5.x 集群。修改 4.x 集群属性的接口文档见 [ModifyRocketMQInstance](https://cloud.tencent.com/document/product/1179/108862)。
         """
         
         kwargs = {}
@@ -1339,7 +1359,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.ModifyRoleResponse:
         """
-        修改角色
+        修改角色。
+        当前 API 适用集群：5.x 集群。4.x 集群的修改角色接口文档见 [ModifyRocketMQRole](https://cloud.tencent.com/document/product/1179/107532)，修改角色的授权接口文档见 [ModifyRocketMQEnvironmentRole](https://cloud.tencent.com/document/product/1179/107533)。
         """
         
         kwargs = {}
@@ -1357,7 +1378,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.ModifyTopicResponse:
         """
-        修改主题属性
+        修改主题属性。
+        当前 API 适用集群：5.x 集群。4.x 集群的修改主题属性接口文档见 [ModifyRocketMQTopic](https://cloud.tencent.com/document/api/1179/63414)。
         """
         
         kwargs = {}
@@ -1412,7 +1434,8 @@ class TrocketClient(AbstractClient):
             opts: Dict = None,
     ) -> models.ResetConsumerGroupOffsetResponse:
         """
-        重置消费位点
+        重置消费位点。
+        当前 API 适用集群：5.x 集群。4.x 集群的重置消费位点接口文档见 [ResetRocketMQConsumerOffSet](https://cloud.tencent.com/document/api/1179/71662)。
         """
         
         kwargs = {}
